<?php
/**
 * 対応ページのパンくずリストを出力する.
 */
function the_topicpath() {
	global $post;
	// メインページのリンク文字列生成
	$news = '<a href="' . home_url('/news/') . '">News</a> &gt; ';
	// タイトル文字列生成
	$title = wp_title('', false);
	$links = "";
	// リンク生成
	if(is_page()) {
		// ページの場合先祖のページを先祖順にパンくずに追加
		$ancestors = array_reverse(get_post_ancestors($post));
		foreach($ancestors as $ancestor) {
			$links  = '<a href="' . get_permalink($ancestor) . '">';
			$links .= get_the_title($ancestor) . '</a>  &gt; ';
		}
	} elseif(is_single()) {
		// 投稿シングルの場合メインページのリンクをパンくずに追加
		$links  = $news;
	} elseif(is_month()) {
		// 月別アーカイブの場合場合メインページのリンクをパンくずに追加
		$links  = $news;
		// タイトル文字列は日本語表記とする
		$title = single_month_title_jp();
	} elseif(is_home()) {
		// 投稿トップの場合メインページのリンクをパンくずに追加
		$links = 'News';
		// タイトル文字列は必要ない
		$title = "";
	}
	// パンくずの一番最初にフロントページを追加し HTML 出力
	echo '<p class="topicpath">';
	echo '<a href="' . home_url('/') . '">Home</a> &gt; ';
	echo $links . $title . '</p>';
}

/**
 * 月別アーカイブタイトルを日本語表記で返却する.
 *
 * @return 月別アーカイブ時のタイトル文字列
 */
function single_month_title_jp() {
	return get_query_var('year') . "年 " . get_query_var('monthnum') . "月";
}

/**
 * 存在しないページを指定された場合に 404 ページを表示する.
 */
function redirect_404() {
	// メインページ・シングルページ・アーカイブ（月別）・ページ以外の指定
	// の場合、404 ページを表示する
	if (is_home() || is_single() || is_month() || is_page()) return;
	include(TEMPLATEPATH . '/404.php');
	exit;	
}
add_filter('template_redirect', 'redirect_404');

/**
 * 固定ページに抜粋を表示する.
 */
add_post_type_support('page', 'excerpt');

/**
 * 固定ページにアイキャッチ画像を表示する.
 */
add_theme_support('post-thumbnails', array('page'));
set_post_thumbnail_size(200, 150, true);

/**
 * 管理画面にエディタースタイルシートを適用する.
 */
add_editor_style();

/**
 * 不要な wp_head() を除去する.(wp-includes/default-filters.php)
 */
remove_action('wp_head', 'feed_links');
remove_action('wp_head', 'feed_links_extra');
remove_action('wp_head', 'rsd_link');
remove_action('wp_head', 'wlwmanifest_link');
remove_action('wp_head', 'adjacent_posts_rel_link_wp_head');

/**
 * 記事に挿入された画像のローカル環境の URL を動作サイトの URL に変換（テスト用）.
 *
 * @param unknown_type $content
 * @return mixed
 */
function change_local_image_path($content) {
	$home = home_url();
	// 記事に添付されている画像取得
	$images = get_children(array(
			'post_parent' => get_the_ID(),
			'post_type' => 'attachment',
			'post_mime_type' => 'image',
			'order' => 'ASC'));
	// テーマで使われている全ての画像サイズを取得
	$sizes = get_intermediate_image_sizes();
	$sizes[] = 'full';
	// 記事に添付されている全ての画像とサイズのパスの変換用配列作成
	$image_from_path = array();
	$image_to_path = array();
	foreach($images as $image) {
		foreach($sizes as $size) {
			$img_src = wp_get_attachment_image_src($image->ID, $size);
			$image_from_path[] =
			"!" . str_replace($home, LOCAL_HOME, $img_src[0]) . "!";
			$image_to_path[] = "${img_src[0]}";
		}
	}
	// 画像の URL を現在動いている home_url に置換して返却
	return preg_replace($image_from_path, $image_to_path, $content);
}
// ローカル環境の WP_HOME を定義
define(LOCAL_HOME, 'http://localhost');
add_filter('the_content', 'change_local_image_path', 999);

/**
 * 管理バー非表示（テスト用）
 */
add_filter('show_admin_bar', create_function('', 'return false;'));
?>
